import { makeStyles } from "@material-ui/core/styles";
import SendMessage from "./SendMessage";
import MessageLeft from './Messages/MessageLeft'
import MessageRight from './Messages/MessagesRight'
import { useState,useEffect,useRef,useCallback} from "react";
import { fakeChat } from "./fakeChat";

const debounce = require('lodash.debounce');

const useStyles = makeStyles({   
    container: {
      width: "100%",
      height: "100%",
      maxWidth: "100%",
      maxHeight: "100%",
      display: "flex",
      alignItems: "center",
      alignContent:"center",
      flexDirection: "column",
      position: "relative",
      overflowY: "scroll",
      paddingTop: 60,
    },
    messagesBody: {
      width: "40%",
      height: "80%",
    },   
});

const timestamp = new Date(2022, 3, 8).toLocaleString("en-US", {
    year:'numeric',
    month: 'short',
    day: 'numeric'
  });

const ChatBar = () => {
  const classes = useStyles();
  const [chat, setChat] = useState<any>(fakeChat)
  const [isArrow,setIsArrow] = useState<boolean>(false)
  const divRef = useRef<HTMLDivElement | null>(null)
  const handleScroll = ({ target }: any) => {
    const different = target.scrollHeight - target.scrollTop
    setIsArrow(different < 1500?false:true)
  }
  const handleArrow = () => {
    divRef.current&&divRef.current.scrollTo({
    top: 1000000,
    behavior: 'smooth'
    })
  }
  const debouncedHandleScroll = useCallback(debounce(handleScroll, 300), []);
  useEffect(() => {
    divRef.current&&divRef.current.scrollTo({
    top: 1000000,
    behavior: 'smooth'
    })
  }, [chat])
 
  return (
      <div ref={divRef} className={classes.container} onScroll={debouncedHandleScroll}>
        <div  className={classes.messagesBody}>
        {chat.map(({message,avatarUrl,name,lastName}:any,i:number) => {
          if (i % 2 === 0) {
            return (
            <MessageLeft
            message={message}
            timestamp={timestamp}
            avatarUrl={avatarUrl}
            name={name}
            lastName={lastName}
          />)
          } else {
            return (
            <MessageRight
            message={message}
            timestamp={timestamp}
            avatarUrl={avatarUrl}
            name={name}
            lastName={lastName}
          />)}})}
      </div>         
      <SendMessage setChat={setChat} isArrow={isArrow} handleArrow={handleArrow}/>   
      </div>
  );
}

export default ChatBar