import { actionIsLoading } from '../../loading/action';
import {
  actionLogInSuccess,
  actionLogInReject,
  actionLogOutSuccess,
  actionLogOutReject,
  actionCurrentSuccess,
  actionCurrentReject
} from '../action';
import { setToken, loginUser, updateCredentials, updateUserAvatar, currentUser } from '../../../api-data';
import { IAuthorizationState } from '../../../typescript/redux/authorization/interfaces'
import { TResPromiseAll } from '../../../typescript/redux/authorization/types'

const asyncCreateUser = (name:string, lastName: string,file:object) => async (dispatch:any) => {
  try {
    dispatch(actionIsLoading(true));
    const formData: any = new FormData()
    formData.append("avatar", file);
    const data = await Promise.all<TResPromiseAll>(
    [updateUserAvatar(formData), updateCredentials(name, lastName)])
    const token = data.find(el => el?.token)?.token
    token&&dispatch(actionLogInSuccess(token))
  } catch (e) {
    dispatch(actionLogInReject())
  } finally {
    dispatch(actionIsLoading(false));
  }
};

const asyncLogin = (number:string, code: string,cb:() => void ) => async (dispatch:any) => {
  try {
    dispatch(actionIsLoading(true));
    const data = await loginUser<{ token: string, registered: boolean }>(number, code);
    const token = data?.token
    const registered = data?.registered
    if (!token) return
    setToken.set(token)
    if (!registered) return cb()
    dispatch(actionLogInSuccess(token))
  } catch (e) {
    dispatch(actionLogInReject());
    cb()
  } finally {
    dispatch(actionIsLoading(false));
  }
};

const asyncLogout = () => async (dispatch:any) => {
  try {
    dispatch(actionIsLoading(true));
    dispatch(actionLogOutSuccess());
    setToken.unset()
  } catch (e) {
    dispatch(actionLogOutReject());
  } finally {
    dispatch(actionIsLoading(false));
  }
};

const asyncCurrentUser = () => async (dispatch:any) => {
  try {
    dispatch(actionIsLoading(true));
    const data = await currentUser<IAuthorizationState>()
    data && dispatch(actionCurrentSuccess(data));
    if(!data?.token) throw new Error('old token')
  } catch (e) {
    dispatch(actionCurrentReject());
  } finally {
    dispatch(actionIsLoading(false));
  }
};

export { asyncCreateUser, asyncLogin, asyncLogout, asyncCurrentUser };
